@@ -2,31 +2,25 @@
 
 const path = require("path");
 const fs = require("fs");
-const request = require("request");
-const mkdirp = require("mkdirp");
+const fetch = require("minipass-fetch");
 
 if (process.env.NO_UPDATE) {
   process.exit(0);
 }
 
-process.on("unhandledRejection", err => {
-  throw err;
-});
-
 // Pin to specific version, reflecting the spec version in the readme.
 //
 // To get the latest commit:
-// 1. Go to https://github.com/w3c/web-platform-tests/tree/master/WebIDL/ecmascript-binding/es-exceptions
+// 1. Go to https://github.com/web-platform-tests/wpt/tree/master/webidl/ecmascript-binding/es-exceptions
 // 2. Press "y" on your keyboard to get a permalink
 // 3. Copy the commit hash
-const commitHash = "d198d67803096e5252bd31735f57eb4db1c975a9";
+const commitHash = "904652fbaa979e6ac1e3c28b6ca0402b0179f62e";
 
-// Have to use RawGit as JSDOM.fromURL checks Content-Type header.
 const urlPrefix = `https://raw.githubusercontent.com/w3c/web-platform-tests/${commitHash}/` +
-                  `WebIDL/ecmascript-binding/es-exceptions/`;
+                  `webidl/ecmascript-binding/es-exceptions/`;
 const targetDir = path.resolve(__dirname, "..", "test", "web-platform-tests");
 
-mkdirp.sync(targetDir);
+fs.mkdirSync(targetDir, { recursive: true });
 
 const files = [
   "DOMException-constants.any.js",
@@ -35,14 +29,14 @@ const files = [
   "DOMException-custom-bindings.any.js"
 ];
 
-for (const file of files) {
-  request(`${urlPrefix}${file}`)
-    .on("error", fail)
-    .pipe(fs.createWriteStream(path.resolve(targetDir, file)))
-    .on("error", fail);
+async function main() {
+  await Promise.all(files.map(async file => {
+    const res = await fetch(`${urlPrefix}${file}`);
+    res.body.pipe(fs.createWriteStream(path.resolve(targetDir, file)));
+  }));
 }
 
-function fail(err) {
+main().catch(err => {
   console.error(err.stack);
   process.exit(1);
-}
+});
